%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% class for LaTeX files            v1.1 Sept-11-2007             %%
%%                                                                %%
%% The regular article class commands still exist and may be used.%%
%% 10pt, 11pt and twocolumn options are disabled.                 %%
%%                                                                %%
%% Class file modified from bits&pieces of other conferences by
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
%\ProvidesClass{FullPaper_Instructions_LaTex_EURODYN2010}

\DeclareOption{10pt}{\OptionNotUsed}
\DeclareOption{11pt}{\OptionNotUsed}
\DeclareOption{twocolumn}{\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\DeclareOption{dvips}{%
  \PassOptionsToPackage{dvips}{hyperref}}
\DeclareOption{pdftex}{%
  \PassOptionsToPackage{pdftex}{hyperref}}
\DeclareOption{dvipdfm}{%
  \PassOptionsToPackage{dvipdfm}{hyperref}}
\DeclareOption{dvips}{%
  \PassOptionsToPackage{dvips}{graphicx}}
\DeclareOption{pdftex}{%
  \PassOptionsToPackage{pdftex}{graphicx}}
\DeclareOption{dvipdfm}{%
  \PassOptionsToPackage{dvipdfm}{graphicx}}

\ProcessOptions\relax

\LoadClass[a4paper,12pt]{article}
\RequirePackage[a4paper,lmargin=27mm, rmargin=27mm, bmargin=25mm, tmargin=15mm]{geometry}
%\RequirePackage[linkcolor=blue,urlcolor=blue,colorlinks=true,citecolor=black]{hyperref}
\RequirePackage{calc}
%\RequirePackage{indentfirst}
\RequirePackage{url}
\RequirePackage{graphicx}
\RequirePackage{times}
\RequirePackage{txfonts}
\usepackage{here}
\usepackage[numbers,sort&compress]{natbib}
\hyphenation{bran-ches pa-ra-me-ters ar-rhyth-mi-a }
\usepackage{fancyhdr}
\renewcommand{\headrulewidth}{0pt}
%% Title
\renewcommand{\maketitle}{%
 \newpage
 \thispagestyle{fancy}
 \begin{flushleft}
\vspace{24pt}~\\
\includegraphics[width=118mm]{logo2013} \\
\vspace{24 pt}
\end{flushleft}
 \begin{flushleft}%
  {%3
 \begin{centering}
   \fontsize{14}{14}\selectfont
   \bfseries
   \MakeUppercase{\@title}
   \par
   \end{centering}}%3
  \vspace{24pt}%
  {%4
\fontsize{12}{12}\selectfont
   \bfseries\@author
   \par
  }%4
  \vspace{14pt}%
  {%5
\fontsize{12}{12}\selectfont
   \def\and{\\\vspace{14pt}}
   \normalfont\@address
   \par
  }%5
 \end{flushleft}
 \vspace{18pt}%
 \noindent\textbf{Keywords:\space}\@keywords
 \par
 \vspace{18pt}%
 \noindent\textbf{\MakeUppercase{Abstract}}\vspace{6pt}\\{\@abstract}
 \par
%% use headers, footers and page number
\pagestyle{fancy}
 }% End of \@maketitle

\def\author{\@ifnextchar[{\@getshortauthor}{\@getauthor}}
\def\@getauthor#1{\gdef\@author{#1}\gdef\@shortauthor{#1}}
\def\@getshortauthor[#1]#2{\gdef\@shortauthor{#1}\gdef\@author{#2}}

\newcommand{\address}[1]{\gdef\@address{#1}}

\newcommand{\keywords}[1]{\gdef\@keywords{#1}}

\renewcommand{\abstract}[1]{\gdef\@abstract{#1}}

\newcommand{\heading}[1]{\gdef\@heading{#1}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%
%%%  The syntax for the definition of section is (see LaTeX Companion p.24)
%%%
%%%   \renewcommand\section{\@startsection {section}{1}{\z@}%
%%%        {-3.5ex \@plus -1ex \@minus -.2ex}%
%%%        {2.3ex \@plus.2ex}%
%%%        {\reset@font\Large\bfseries}}
%%%
%%%  Explication :
%%%  + {section} name of the sectioning command.
%%%  + {1} Number denoting the depth level of the sectioning command.
%%%  + {\z@} Indentation of the heading (zero).
%%%  + {-3.5ex \@plus -1ex \@minus -.2ex} defined the space to be left
%%%             in front of the heading.
%%%  + {2.3ex \@plus.2ex} defined the space to be left following
%%%             a heading.  If this number is under zero, the
%%%             space is horizontal, in order to have horizontal title
%%%             like :
%%%             Section title.   Here is the text of my section ...
%%%  + \@plus and \@minus allow to stretch and shrink component.
%%%  + {\reset@font\Large\bfseries} Style of the heading text.
%%%
%%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\renewcommand{\thesection}      {\arabic{section}.}
\pagestyle{fancy}
\renewcommand{\section}{\@startsection {section}{1}{0mm}%
                                   {-\baselineskip}%
                                   {0.5\baselineskip}%
                                   {\bfseries\normalsize\MakeUppercase}}

\renewcommand{\thesubsection}   {\thesection\arabic{subsection}}

\renewcommand{\subsection}{\@startsection{subsection}{2}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\bfseries\normalsize}}

\renewcommand\thesubsubsection{\thesubsection\@arabic\c@subsubsection}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalfont\scriptsize\bfseries}}

%% No headings have number
\setcounter{secnumdepth}{2}



\renewcommand{\@makecaption}[2]{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{\normalsize\fontsize{12}{12}\selectfont #1. #2}%
  \ifdim \wd\@tempboxa >\hsize
    \normalsize\fontsize{12}{12}\selectfont #1: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

\renewenvironment{thebibliography}[1]
  {\bigskip
  \section*{\MakeUppercase\refname\@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}}%
  \list{\@biblabel{\@arabic\c@enumiv}}%
        {\settowidth\labelwidth{\@biblabel{#1}}%
         \leftmargin\labelwidth
         \advance\leftmargin\labelsep
         \@openbib@code
         \usecounter{enumiv}%
         \let\p@enumiv\@empty
         \renewcommand\theenumiv{\@arabic\c@enumiv}}%
   \sloppy
   \clubpenalty4000
   \@clubpenalty \clubpenalty
   \widowpenalty4000%
   \sfcode`\.\@m}
  {\def\@noitemerr
   {\@latex@warning{Empty `thebibliography' environment}}%
   \endlist}

\setlength{\parindent}{5mm}

\AtBeginDocument{%
  \pagestyle{fancy}
  \maketitle
  \let\maketitle\relax
}
\def\refname{REFERENCES}
\RequirePackage{natbib}
\setlength{\bibsep}{0.5pt} % Get rid of the spacing between references
\bibliographystyle{unsrt}

%% Do not use headers, footers and page number
\pagestyle{fancy}

\endinput
